<?php
/**
 * @file
 * Contains wrapper code for a BazaarvoiceProductFeed object.
 */

/**
 * Class BazaarvoiceProductFeed.
 */
class BazaarvoiceProductFeed extends Bazaarvoice {

  private $ftpHost;
  private $ftpUsername;
  private $ftpPassword;

  /**
   * Construct function.
   */
  public function __construct() {
    $bazaarvoice_mode = variable_get('bazaarvoice_mode', 'stg');
    $this->ftpHost = 'sftp' . ($bazaarvoice_mode == 'stg' ? '-stg' : '') . '.bazaarvoice.com';
    $this->ftpUsername = variable_get('bazaarvoice_ftp_username', NULL);
    $this->ftpPassword = variable_get('bazaarvoice_ftp_password', NULL);
    parent::__construct();
  }

  /**
   * Attempt to FTP file to Bazaarvoice.
   *
   * @param string $file_path
   *   Path to feedfile to FTP.
   *
   * @return bool
   *   Boolean status if FTP was successful.
   */
  public function ftpProductFeed($file_path) {
    $file_sent = FALSE;

    $ftp_path = "/import-inbox/" . basename($file_path);
    // @TODO: abstract this out into a new class?
    // Check to see if SSH2 PHP extension is installed.
    if (function_exists('ssh2_connect')) {
      try {
        // Create an ssh connection.
        $connection = ssh2_connect($this->ftpHost, '22');
        // Attempt to authenticate.
        ssh2_auth_password($connection, $this->ftpUsername, $this->ftpPassword);
        // Create an sftp connection.
        $sftp = ssh2_sftp($connection);
        // Get full remote path.
        $remote_dir = ssh2_sftp_realpath($sftp, ".");
        // Open up a file stream for writing.
        $stream = fopen('ssh2.sftp://' . $sftp . $remote_dir . $ftp_path, 'w');
        // Attempt to write to stream.
        if (fwrite($stream, file_get_contents($file_path))) {
          $file_sent = TRUE;
        }
        // Else attempt file_put_contents.
        elseif (file_put_contents('ssh2.sftp://' . $sftp . '/' . $remote_dir . $ftp_path, file_get_contents($file_path))) {
          $file_sent = TRUE;
        }
        // Close file stream.
        fclose($stream);
      }
      catch (Exception $e) {
        $file_sent = $e->getMessage();
      }
    }
    else {
      $file_sent = 'SSH2 PHP extension not enabled.';
    }

    return $file_sent;
  }

}
